@@ -21,37 +21,19 @@
 # THE SOFTWARE.
 
 import pydoc
+
 import bpython._internal
 
 
-class NopPydocPager:
-    def __enter__(self):
-        self._orig_pager = pydoc.pager
-        pydoc.pager = self
-
-    def __exit__(self, *args):
-        pydoc.pager = self._orig_pager
-
-    def __call__(self, text):
-        return None
-
-
 class _Helper(bpython._internal._Helper):
+
     def __init__(self, repl=None):
         self._repl = repl
         pydoc.pager = self.pager
 
-        super().__init__()
+        super(_Helper, self).__init__()
 
     def pager(self, output):
         self._repl.pager(output)
 
-    def __call__(self, *args, **kwargs):
-        if self._repl.reevaluating:
-            with NopPydocPager():
-                return super().__call__(*args, **kwargs)
-        else:
-            return super().__call__(*args, **kwargs)
-
-
 # vim: sw=4 ts=4 sts=4 ai et
