@@ -22,42 +22,36 @@ class StatusBar(BpythonInteraction):
     functionality in a evented or callback style, but trying to integrate
     bpython.Repl code.
     """
-
-    def __init__(
-        self,
-        config,
-        permanent_text="",
-        request_refresh=lambda: None,
-        schedule_refresh=lambda when: None,
-    ):
-        self._current_line = ""
+    def __init__(self,
+                 permanent_text="",
+                 request_refresh=lambda: None,
+                 schedule_refresh=lambda when: None):
+        self._current_line = ''
         self.cursor_offset_in_line = 0
         self.in_prompt = False
         self.in_confirm = False
         self.waiting_for_refresh = False
-        self.prompt = ""
-        self._message = ""
+        self.prompt = ''
+        self._message = ''
         self.message_start_time = time.time()
         self.message_time = 3
         self.permanent_stack = []
         if permanent_text:
             self.permanent_stack.append(permanent_text)
-        self.main_context = greenlet.getcurrent()
-        self.request_context = None
+        self.main_greenlet = greenlet.getcurrent()
+        self.request_greenlet = None
         self.request_refresh = request_refresh
         self.schedule_refresh = schedule_refresh
 
-        super().__init__(config)
-
     def push_permanent_message(self, msg):
-        self._message = ""
+        self._message = ''
         self.permanent_stack.append(msg)
 
     def pop_permanent_message(self, msg):
         if msg in self.permanent_stack:
             self.permanent_stack.remove(msg)
         else:
-            raise ValueError("Message %r was not in permanent_stack" % msg)
+            raise ValueError("Messsage %r was not in permanent_stack" % msg)
 
     @property
     def has_focus(self):
@@ -71,29 +65,26 @@ class StatusBar(BpythonInteraction):
             self.schedule_refresh(time.time() + self.message_time)
 
     def _check_for_expired_message(self):
-        if (
-            self._message
-            and time.time() > self.message_start_time + self.message_time
-        ):
-            self._message = ""
+        if (self._message and
+                time.time() > self.message_start_time + self.message_time):
+            self._message = ''
 
     def process_event(self, e):
         """Returns True if shutting down"""
         assert self.in_prompt or self.in_confirm or self.waiting_for_refresh
         if isinstance(e, RefreshRequestEvent):
             self.waiting_for_refresh = False
-            self.request_context.switch()
+            self.request_greenlet.switch()
         elif isinstance(e, events.PasteEvent):
             for ee in e.events:
                 # strip control seq
                 self.add_normal_character(ee if len(ee) == 1 else ee[-1])
-        elif e == "<ESC>" or isinstance(e, events.SigIntEvent):
-            self.request_context.switch(False)
+        elif e in ['<ESC>'] or isinstance(e, events.SigIntEvent):
+            self.request_greenlet.switch(False)
             self.escape()
         elif e in edit_keys:
             self.cursor_offset_in_line, self._current_line = edit_keys[e](
-                self.cursor_offset_in_line, self._current_line
-            )
+                self.cursor_offset_in_line, self._current_line)
         elif e == "<Ctrl-c>":  # TODO can this be removed?
             raise KeyboardInterrupt()
         elif e == "<Ctrl-d>":  # TODO this isn't a very intuitive behavior
@@ -101,34 +92,32 @@ class StatusBar(BpythonInteraction):
         elif self.in_prompt and e in ("\n", "\r", "<Ctrl-j>", "Ctrl-m>"):
             line = self._current_line
             self.escape()
-            self.request_context.switch(line)
+            self.request_greenlet.switch(line)
         elif self.in_confirm:
-            if e in ("y", "Y"):
-                self.request_context.switch(True)
+            if e in ('y', 'Y'):
+                self.request_greenlet.switch(True)
             else:
-                self.request_context.switch(False)
+                self.request_greenlet.switch(False)
             self.escape()
         else:  # add normal character
             self.add_normal_character(e)
 
     def add_normal_character(self, e):
-        if e == "<SPACE>":
-            e = " "
+        if e == '<SPACE>':
+            e = ' '
         if len(e) > 1:
             return
-        self._current_line = (
-            self._current_line[: self.cursor_offset_in_line]
-            + e
-            + self._current_line[self.cursor_offset_in_line :]
-        )
+        self._current_line = (self._current_line[:self.cursor_offset_in_line] +
+                              e +
+                              self._current_line[self.cursor_offset_in_line:])
         self.cursor_offset_in_line += 1
 
     def escape(self):
         """unfocus from statusbar, clear prompt state, wait for notify call"""
         self.in_prompt = False
         self.in_confirm = False
-        self.prompt = ""
-        self._current_line = ""
+        self.prompt = ''
+        self._current_line = ''
 
     @property
     def current_line(self):
@@ -141,7 +130,7 @@ class StatusBar(BpythonInteraction):
             return self._message
         if self.permanent_stack:
             return self.permanent_stack[-1]
-        return ""
+        return ''
 
     @property
     def should_show_message(self):
@@ -149,26 +138,26 @@ class StatusBar(BpythonInteraction):
 
     # interaction interface - should be called from other greenlets
     def notify(self, msg, n=3, wait_for_keypress=False):
-        self.request_context = greenlet.getcurrent()
+        self.request_greenlet = greenlet.getcurrent()
         self.message_time = n
         self.message(msg, schedule_refresh=wait_for_keypress)
         self.waiting_for_refresh = True
         self.request_refresh()
-        self.main_context.switch(msg)
+        self.main_greenlet.switch(msg)
 
     # below Really ought to be called from greenlets other than main because
     # they block
     def confirm(self, q):
         """Expected to return True or False, given question prompt q"""
-        self.request_context = greenlet.getcurrent()
+        self.request_greenlet = greenlet.getcurrent()
         self.prompt = q
         self.in_confirm = True
-        return self.main_context.switch(q)
+        return self.main_greenlet.switch(q)
 
     def file_prompt(self, s):
         """Expected to return a file name, given """
-        self.request_context = greenlet.getcurrent()
+        self.request_greenlet = greenlet.getcurrent()
         self.prompt = s
         self.in_prompt = True
-        result = self.main_context.switch(s)
+        result = self.main_greenlet.switch(s)
         return result
