@@ -1,12 +1,15 @@
-# encoding: utf-8
-
 import sys
 
-from bpython.test import mock, unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
+
 from bpython.curtsiesfrontend.coderunner import CodeRunner, FakeOutput
 
 
 class TestCodeRunner(unittest.TestCase):
+
     def setUp(self):
         self.orig_stdout = sys.stdout
         self.orig_stderr = sys.stderr
@@ -16,24 +19,20 @@ class TestCodeRunner(unittest.TestCase):
         sys.stderr = self.orig_stderr
 
     def test_simple(self):
-        c = CodeRunner(
-            request_refresh=lambda: self.orig_stdout.flush()
-            or self.orig_stderr.flush()
-        )
+        c = CodeRunner(request_refresh=lambda: self.orig_stdout.flush() or
+                       self.orig_stderr.flush())
         stdout = FakeOutput(c, lambda *args, **kwargs: None)
         stderr = FakeOutput(c, lambda *args, **kwargs: None)
         sys.stdout = stdout
         sys.stdout = stderr
-        c.load_code("1 + 1")
+        c.load_code('1 + 1')
         c.run_code()
         c.run_code()
         c.run_code()
 
     def test_exception(self):
-        c = CodeRunner(
-            request_refresh=lambda: self.orig_stdout.flush()
-            or self.orig_stderr.flush()
-        )
+        c = CodeRunner(request_refresh=lambda: self.orig_stdout.flush() or
+                       self.orig_stderr.flush())
 
         def ctrlc():
             raise KeyboardInterrupt()
@@ -42,14 +41,5 @@ class TestCodeRunner(unittest.TestCase):
         stderr = FakeOutput(c, lambda *args, **kwargs: None)
         sys.stdout = stdout
         sys.stderr = stderr
-        c.load_code("1 + 1")
+        c.load_code('1 + 1')
         c.run_code()
-
-
-class TestFakeOutput(unittest.TestCase):
-    def assert_unicode(self, s):
-        self.assertIsInstance(s, type(u""))
-
-    def test_bytes(self):
-        out = FakeOutput(mock.Mock(), self.assert_unicode)
-        out.write("native string type")
